@@ -47,6 +47,10 @@ If you go to the configuration file directory, there will
 be example configuration files for the different runs that 
 you have performed.
 
+=head3 --info
+
+This prints out the relation and source information of the children
+
 =head3 --debug
 
 Sets the debug flag for testing
@@ -145,7 +149,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "file=s")) or die ("Please check the above mentioned option(s).\n");
+eval(GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "file=s", "info")) or die ("Please check the above mentioned option(s).\n");
 
 
 #  if help is defined, print out help
@@ -266,7 +270,13 @@ foreach my $input (@terms) {
 	    print "The children of $term ($cui) are: \n";
 	    foreach my $child (@children) {
 		my ($t) = $umls->getTermList($child);
-		print "  $t($child)\n";
+		print "  $t ($child) ";
+		if(defined $opt_info) {
+		    my @relations = $umls->getRelationsBetweenCuis($cui, $child);
+		    &errorCheck($umls);
+		    print " => @relations";
+		}
+		print "\n";
 	    } 
 	}
 	$printFlag = 1;
@@ -312,6 +322,9 @@ sub showHelp() {
 
     print "--debug                  Sets the debug flag for testing\n\n";
 
+    print "--info                   This prints out the relation and source\n";
+    print "                         of the children\n\n";
+
     print "--username STRING        Username required to access mysql\n\n";
 
     print "--password STRING        Password required to access mysql\n\n";
@@ -333,7 +346,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getChildren.pl,v 1.11 2010/05/11 20:04:46 btmcinnes Exp $';
+    print '$Id: getChildren.pl,v 1.12 2010/05/12 15:41:47 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
